Crate hyper_trust_dns[−][src]
This crate provides HTTP/HTTPS connectors for hyper that use the fast and advanced DNS resolver of trust-dns instead of the default threadpool implementation of hyper.
Types of connectors
There are 3 connectors:
TrustDnsHttpConnector, a wrapper aroundHttpConnector<TrustDnsResolver>. Created withnew_trust_dns_http_connector.RustlsHttpsConnector, a hyper-rustls based connector to work withTrustDnsHttpConnector. Created withnew_rustls_webpki_https_connectorornew_rustls_native_https_connector.NativeTlsHttpsConnector, a hyper-tls based connector to work withTrustDnsHttpConnector. Created withnew_native_tls_https_connector.
The HTTP connector is always available, the other two can be enabled via the rustls-webpki (uses webpki roots)/rustls-native (uses OS cert store) and native-tls features respectably.
Trust-DNS options
The crate has other features that toggle functionality in trust-dns-resolver, namingly dns-over-openssl, dns-over-native-tls and dns-over-rustls for DNS-over-TLS, dns-over-https-rustls for DNS-over-HTTPS and dnssec-openssl and dnssec-ring for DNSSEC.
Structs
Iterator over DNS lookup results.
A hyper resolver using trust-dns’s TokioAsyncResolver.
Functions
native-tlsCreate a new NativeTlsHttpsConnector.
rustls-nativeCreate a new RustlsHttpsConnector using the OS root store.
rustls-webpkiCreate a new RustlsHttpsConnector using the webpki_roots.
Create a new TrustDnsHttpConnector that only supports HTTP.
Type Definitions
native-tlsA HttpsConnector that uses a TrustDnsHttpConnector.
rustls-native or rustls-webpkiA HttpsConnector that uses a TrustDnsHttpConnector.
A HttpConnector that uses the TrustDnsResolver.