pub struct TrustDnsResolver { /* private fields */ }
A hyper resolver using trust-dns’s TokioAsyncResolver.

Implementations

Create a new TrustDnsResolver with the default config options. This must be run inside a Tokio runtime context.

Create a new TrustDnsResolver that uses the Google nameservers. This must be run inside a Tokio runtime context.

Create a new TrustDnsResolver that uses the Cloudflare nameservers. This must be run inside a Tokio runtime context.

This is supported on crate feature dns-over-https only.

Create a new TrustDnsResolver that uses the Cloudflare nameservers. This limits the registered connections to just HTTPS lookups. This must be run inside a Tokio runtime context.

This is supported on crate feature dns-over-tls only.

Create a new TrustDnsResolver that uses the Cloudflare nameservers. This limits the registered connections to just TLS lookups. This must be run inside a Tokio runtime context.

Create a new TrustDnsResolver that uses the Quad9 nameservers. This must be run inside a Tokio runtime context.

This is supported on crate feature dns-over-https only.

Create a new TrustDnsResolver that uses the Quad9 nameservers. This limits the registered connections to just HTTPS lookups. This must be run inside a Tokio runtime context.

This is supported on crate feature dns-over-tls only.

Create a new TrustDnsResolver that uses the Quad9 nameservers. This limits the registered connections to just TLS lookups. This must be run inside a Tokio runtime context.

Create a new TrustDnsResolver with the resolver configuration options specified. This must be run inside a Tokio runtime context.

This is supported on crate feature system-config only.

Create a new TrustDnsResolver with the system configuration. This must be run inside a Tokio runtime context.

Create a new TrustDnsHttpConnector with this resolver.

This is supported on crate feature native-tls only.
This is supported on crate feature rustls-native only.

Create a new RustlsHttpsConnector using the OS root store.

This is supported on crate feature rustls-webpki only.

Create a new RustlsHttpsConnector using the webpki_roots.