Struct hyper_trust_dns::TrustDnsResolver
source · [−]pub struct TrustDnsResolver { /* private fields */ }Expand description
A hyper resolver using trust-dns’s TokioAsyncResolver.
Implementations
sourceimpl TrustDnsResolver
impl TrustDnsResolver
sourcepub fn new() -> Self
pub fn new() -> Self
Create a new TrustDnsResolver with the default config options.
This must be run inside a Tokio runtime context.
sourcepub fn google() -> Self
pub fn google() -> Self
Create a new TrustDnsResolver that uses the Google nameservers.
This must be run inside a Tokio runtime context.
sourcepub fn cloudflare() -> Self
pub fn cloudflare() -> Self
Create a new TrustDnsResolver that uses the Cloudflare nameservers.
This must be run inside a Tokio runtime context.
sourcepub fn cloudflare_https() -> Self
This is supported on crate feature dns-over-https only.
pub fn cloudflare_https() -> Self
dns-over-https only.Create a new TrustDnsResolver that uses the Cloudflare nameservers.
This limits the registered connections to just HTTPS lookups.
This must be run inside a Tokio runtime context.
sourcepub fn cloudflare_tls() -> Self
This is supported on crate feature dns-over-tls only.
pub fn cloudflare_tls() -> Self
dns-over-tls only.Create a new TrustDnsResolver that uses the Cloudflare nameservers.
This limits the registered connections to just TLS lookups.
This must be run inside a Tokio runtime context.
sourcepub fn quad9() -> Self
pub fn quad9() -> Self
Create a new TrustDnsResolver that uses the Quad9 nameservers.
This must be run inside a Tokio runtime context.
sourcepub fn quad9_https() -> Self
This is supported on crate feature dns-over-https only.
pub fn quad9_https() -> Self
dns-over-https only.Create a new TrustDnsResolver that uses the Quad9 nameservers.
This limits the registered connections to just HTTPS lookups.
This must be run inside a Tokio runtime context.
sourcepub fn quad9_tls() -> Self
This is supported on crate feature dns-over-tls only.
pub fn quad9_tls() -> Self
dns-over-tls only.Create a new TrustDnsResolver that uses the Quad9 nameservers.
This limits the registered connections to just TLS lookups.
This must be run inside a Tokio runtime context.
sourcepub fn with_config_and_options(
config: ResolverConfig,
options: ResolverOpts
) -> Self
pub fn with_config_and_options(
config: ResolverConfig,
options: ResolverOpts
) -> Self
Create a new TrustDnsResolver with the resolver configuration
options specified.
This must be run inside a Tokio runtime context.
sourcepub fn from_system_conf() -> Self
This is supported on crate feature system-config only.
pub fn from_system_conf() -> Self
system-config only.Create a new TrustDnsResolver with the system configuration.
This must be run inside a Tokio runtime context.
sourcepub fn into_http_connector(self) -> TrustDnsHttpConnector
pub fn into_http_connector(self) -> TrustDnsHttpConnector
Create a new TrustDnsHttpConnector with this resolver.
sourcepub fn into_native_tls_https_connector(self) -> NativeTlsHttpsConnector
This is supported on crate feature native-tls only.
pub fn into_native_tls_https_connector(self) -> NativeTlsHttpsConnector
native-tls only.Create a new NativeTlsHttpsConnector.
sourcepub fn into_rustls_native_https_connector(self) -> RustlsHttpsConnector
This is supported on crate feature rustls-native only.
pub fn into_rustls_native_https_connector(self) -> RustlsHttpsConnector
rustls-native only.Create a new RustlsHttpsConnector using the OS root store.
sourcepub fn into_rustls_webpki_https_connector(self) -> RustlsHttpsConnector
This is supported on crate feature rustls-native only.
pub fn into_rustls_webpki_https_connector(self) -> RustlsHttpsConnector
rustls-native only.Create a new RustlsHttpsConnector using the webpki_roots.